/*
  bootloaderconfig.h - part of AVRUSBBoot firmware

  Thomas Fischl <tfischl@gmx.de>

  License:
  The project is built with AVR USB driver by Objective Development, which is
  published under a proprietary Open Source license. To conform with this
  license, USBasp is distributed under the same license conditions. See
  documentation.

  Creation Date..: 2006-03-18
  Last change....: 2006-06-25

  To adapt the bootloader to your hardware, you have to modify the following files:
  - bootloaderconfig.h (this file):
    Define the condition when the bootloader should be started and the initialisation of the
    hardware
  - usbconfig.h:
    Define the used data line pins. You have to adapt USB_CFG_IOPORT, USB_CFG_DMINUS_BIT and 
    USB_CFG_DPLUS_BIT to your hardware. The rest should be left unchanged.

  [2009-08-25] Ilya Danilov: 
                - bootLoaderInit/leaveBootloader/bootLoaderCondition used form
                  USBasp project
                - ATMEGA*8 supported
                - replaced v-usb with release 20090415
                - changed USB_CFG_VENDOR_NAME / USB_CFG_DEVICE_NAME (for using with SMPReaderUSB 
                  project)

               See http://mk90.blogspot.com/search/label/V-USB for details (russian)

*/

#ifndef __bootloaderconfig_h_included__
#define __bootloaderconfig_h_included__

#ifndef __ASSEMBLER__   /* assembler cannot parse function definitions */

#define JUMPER_PORT PORTC /* port with jumper "bootloader active" */
#define JUMPER_PIN  PINC  /* input PIN group with jumper */
#define JUMPER_BIT  2     /* jumper is connected to this bit in JUMPER_PORT, active low */


#ifndef MCUCSR          /* compatibility between ATMega8 and ATMega88 */
#   define MCUCSR   MCUSR
#endif

static inline void  bootLoaderInit(void)
{
    JUMPER_PORT |= (1 << JUMPER_BIT);     /* activate pull-up */
    //if(!(MCUCSR & (1 << EXTRF)))    /* If this was not an external reset, ignore */
    if(!(MCUCSR & (1 << PORF)))    /* If this was not an external reset, ignore */
        leaveBootloader();
    MCUCSR = 0;                     /* clear all reset flags for next time */
}

static inline void  bootLoaderExit(void)
{
    JUMPER_PORT = 0;                      /* undo bootLoaderInit() changes */
}

#define bootLoaderCondition()   ((JUMPER_PIN & (1 << JUMPER_BIT)) == 0)

#endif /* __ASSEMBLER__ */

#endif /* __bootloader_h_included__ */
